# References

While developing Cadwyn, I went through countless resources on API versioning. The following are the most unique and helpful ones I managed to find.

## Cadwyn-style API versioning

### Articles

* [API versioning at Stripe](https://stripe.com/blog/api-versioning)
* [API versioning at Intercom](https://www.intercom.com/blog/api-versioning/)
* [Rolling versions at Convoy](https://getconvoy.io/blog/rolling-versions)
* [Breaking things without breaking things at Keygen](https://keygen.sh/blog/breaking-things-without-breaking-things/)
* [API versioning at LinkedIn Marketing](https://engineering.linkedin.com/blog/2022/-under-the-hood--how-we-built-api-versioning-for-linkedin-market)

### Projects

#### Python

* [Django REST framework versioning](https://github.com/binnev/djangorestframework_versioning)

#### Golang

* [Pinned](https://github.com/sjkaliski/pinned)
* [Request migrations for Go](https://github.com/subomi/requestmigrations) (by the author of Convoy)

#### Ruby

* [Gates](https://github.com/phillbaker/gates)
* [Request migrations for Ruby](https://github.com/keygen-sh/request_migrations)

#### PHP

* [Laravel API migrations](https://github.com/lukepolo/laravel-api-migrations)
* [Request migrations for PHP](https://github.com/tomschlick/request-migrations)

## Overview articles on API versioning

* [Developing an API](https://smartlogic.io/blog/2012-12-12-developing-an-api/)
* [API versioning has no right way](https://apisyouwonthate.com/blog/api-versioning-has-no-right-way/)
* [The tricks of API versioning](https://thenewstack.io/tricks-api-versioning/)
* [Versioning API in Django REST framework](https://studygyaan.com/django/versioning-api-in-django-rest-framework)

## Other articles on API versioning

* [Postman API Platform: API versioning](https://www.postman.com/api-platform/api-versioning/)
* [Four REST API versioning strategies](https://www.xmatters.com/blog/blog-four-rest-api-versioning-strategies)
* [The ultimate guide to microservices versioning: best practices](https://www.opslevel.com/resources/the-ultimate-guide-to-microservices-versioning-best-practices)
* [ASP.NET API versioning on GitHub](https://github.com/dotnet/aspnet-api-versioning)
* [API versioning at SuperJob](https://habr.com/ru/companies/superjob/articles/577650/)
* [Better API versioning with semantic versioning in Django REST framework](https://mikehelmick.medium.com/django-rest-framework-better-api-versioning-with-semantic-versioning-d93908613dea)
* [How Badoo versions its API for internal clients](https://youtu.be/M2KCu0Oq3JE)
